package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@(!`0````````````(`/@`!````4"5```````!``````````!#E````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$````````3:````````!-H`````````
M`"````````$````&````R-T```````#(W6```````,C=8```````X`0`````
M``!@%0``````````(````````@````8```#PW0```````/#=8```````\-U@
M``````#P`0```````/`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````"``````````(``````````$`````````%#E=&0$
M````D-0```````"0U$```````)#40```````'`$````````<`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"`````````!2Y71D!````,C=````````R-U@``````#(W6``
M`````#@"````````.`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````#P``````
M``!A````<@````H``````````````$(`````````2````$<`````````````
M`&4````^````.`````P````:````80`````````P````4P```%0```!.````
M9@```&\```!+````/P``````````````%P```%X````R``````````````!5
M````8````%P````)`````````'````!8````)0```$T`````````0P``````
M``!?`````````%(```!!``````````````!J````"P`````````K````````
M``````!=````-````$0```!&```````````````\`````````$``````````
M`````"0`````````'P```!T````]````2@```"````!M``````````````!G
M````<0```#H````;````3````"X````S``````````T`````````````````
M``!K````:0````````!%````6P```"@````[````+0```#$`````````````
M````````````````````````````````````````````````````````````
M:``````````$```````````````#````````````````````!0``````````
M````#P````````!D`````````!8``````````````&,`````````$```````
M``````````````````!L````````````````````'@````````!B````````
M`!0``````````````"\````F````"```````````````)P````X````U````
M4````"$````5```````````````J````'````%8````1``````````<`````
M````40```"P`````````5P```"D`````````20````8`````````````````
M```2`````````````````````````#8````8````-P``````````````````
M`!D````"````;@```"(````Y`````````",```````````````$`````````
M``````````!9`````````````````````````!,```!/`````````%H`````
M````$0```$X````$````"````"`0$``%0`2$J@)``(*6`:A"*``@22`$"[BB
M.$VZ!`:*3@```$\```!4````60```%H```!A````8P```&4```!G````:@``
M``````!L````;@```&\```!P`````````'$```![\$IKZM/O#F[%WQ]@%LE9
MSMY'+6M_FGPNQ9NVU&34?'Q!CL4@_^0.N8WQ#MEQ6!SB1\8!L@&+;ZQ+X\#"
MY3\LNN.2?/+;TQW[H6Q@:@E#UH?YG(%FK\QFQ;F<0,2)!9!#1=7L#!3BGLC5
MLG%'[#,Z,F+;[=O-XYX,.I<+I]VC:W^IG)OAIP(*H^#[2>?_,*(`````````
M````````````````````````````UP(``!(`````````````````````````
ML0```!(`````````````````````````H0$``!(`````````````````````
M````H0,``!(`````````````````````````ZP(``!(`````````````````
M````````>@(``!(`````````````````````````?@,``!(`````````````
M````````````$0```"``````````````````````````(````"``````````
M````````````````C0$``!(`````````````````````````X@,``!(`````
M````````````````````,@,``!(`````````````````````````;@$``!(`
M````````````````````````@`$``!(`````````````````````````(`,`
M`!(`````````````````````````$0,``!(`````````````````````````
M/P,``!(`````````````````````````D0(``!(`````````````````````
M````"00``!(`````````````````````````+`(``!(`````````````````
M````````_0```!(`````````````````````````'`(``!(`````````````
M````````````:0,``!(`````````````````````````KP,``!(`````````
M````````````````R@$``!(`````````````````````````A0,``!(`````
M````````````````````Y@0``!(`````````````````````````F`(``!(`
M````````````````````````Z@$``!(`````````````````````````-0(`
M`!(`````````````````````````I@$``!(`````````````````````````
MF@,``!(`````````````````````````O`,``!(`````````````````````
M````+P$``!(`````````````````````````-````!(`````````````````
M````````Q`,``!(`````````````````````````-P,``!(`````````````
M````````````70$``!(`````````````````````````R````!(`````````
M````````````````\0(``!(`````````````````````````J`,``!(`````
M````````````````````00$``!(`````````````````````````V0,``!(`
M````````````````````````7`(``!(`````````````````````````M0,`
M`!(`````````````````````````\P,``!(`````````````````````````
M+P0``!(`````````````````````````3@(``!(`````````````````````
M````^`(``!(`````````````````````````C`,``!(`````````````````
M````````JP$``!(`````````````````````````6`,``!(`````````````
M`````````````@0``!(`````````````````````````DP,``!(`````````
M````````````````[````!(`````````````````````````0@```!(`````
M````````````````````T@,``!(`````````````````````````UP```!(`
M````````````````````````_@$``!(`````````````````````````4`,`
M`!(`````````````````````````)00``!(`````````````````````````
MA0(``!(`````````````````````````"0,``!(`````````````````````
M````4`$``!(`````````````````````````1P,``!(`````````````````
M````````'0$``!(`````````````````````````^P,``!(`````````````
M````````````=@,``!(`````````````````````````0P(``!(`````````
M````````````````5````!(`````````````````````````V`$``!(`````
M````````````````````8P```!(`````````````````````````CP```!(`
M````````````````````````Z0,``!(`````````````````````````<`,`
M`!(`````````````````````````>````!(`````````````````````````
M"P$``!(`````````````````````````:@(``!(```"@(D``````````````
M````B`0``!(`#@`H>$``````````````````[P0``!(`#0"M:T```````'$`
M````````^P0``!$`&`"@XF````````@`````````:04``!(`#0"B84``````
M`&P(````````%@0``!(`#0`2=$```````/H"````````8`0``!(`#0!(+$``
M``````L`````````C@0``!(`#0"P;D````````L%````````/@4``!(`#0!=
M;D```````%,`````````B`4``!(`#0!3+$```````.8"````````*`4``!(`
M"P!(($``````````````````3P0``!``\?^HXF``````````````````<00`
M`!(`#0`Y+T```````%$`````````I`0``!(`#0"R,D```````%T`````````
M"@4``!$`#P!`>$````````0`````````)@4``!(`#0`\)D```````#X`````
M````6P0``!``\?\H\V``````````````````HP(``!$`&0#0XF```````!,`
M````````=@4``!(`#0`U8$```````&T!````````&04``!``&`!PXF``````
M````````````H````!(```"P(D``````````````````R`0``!(`#0"*+T``
M`````"4!````````&P0``!$`&0#`XF````````@`````````'`0``"$`&0#`
MXF````````@`````````2`0``!``\?^HXF``````````````````?@0``!(`
M#0`P=T````````(`````````MP$``!(```#@($``````````````````6@4`
M`!$`&`"8XF````````@`````````'P4``!(`#0!0)4``````````````````
M+@4``!(`#0!`=T```````(D`````````&P4``"``&`!PXF``````````````
M````'00``"$`&0#`XF````````@`````````U`0``!(`#0!!7T```````$``
M````````L@0``!(`#0`I*T```````!\!````````E04``!(`#0"O,$``````
M``,"````````7P4``!$`#P`@>T```````&Y9`````````&QI8G!E<FPN<V\N
M-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?
M<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R
M;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L
M7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI
M;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S
M=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%])
M:6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`
M<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P
M='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E
M<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R
M87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`
M;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET
M`'-P<FEN=&8`<W1R;F-M<`!C;&]S961I<@!S=')N8W!Y`%]?<W1A8VM?8VAK
M7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D
M=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!O
M<&5N9&ER`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V<`!R
M96%D9&ER-C0`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M
M86EN`%]?96YV:7)O;@!?7WAS=&%T-C0`7U]L>'-T870V-`!L:6)C<GEP="YS
M;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R
M7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``<VEZ95]L;V%D7VUE7S(`7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T
M`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%
M05)35$%#2P!N86UE7VQO861?;65?,@!P87)?;6MT;7!D:7(`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`
M1TQ)0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#7S(N,BXU`````@```````P`"
M`````P`````````#``,```````0``@`#``,``P`````````#``,````#``,`
M`````````P`#``,```````4``P```````@`#`````P````,``P`#`````@`#
M````!@`#``,```````,```````,``P````(````#`````P`#````````````
M```#``,``````````0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0``
M``$``0````$``P`#``$``0````$``0`!``$``P`!``$``0`!``````````$`
M!``6`P``$````%`````4:6D-```&`*(%```0````$VEI#0``!0"L!0``$```
M`'(9:0D```0`M@4``!````!U&FD)```#`,(%`````````0`!`,<"```0````
M`````'4::0D```(`P@4```````#@WV````````8````(``````````````#`
MXF````````4```!D``````````````#0XF````````4```!?````````````
M````X&````````<````!```````````````(X&````````<````"````````
M```````0X&````````<````#```````````````8X&````````<````$````
M```````````@X&````````<````%```````````````HX&````````<````&
M```````````````PX&````````<````'```````````````XX&````````<`
M``!H``````````````!`X&````````<````*``````````````!(X&``````
M``<````+``````````````!0X&````````<````,``````````````!8X&``
M``````<````-``````````````!@X&````````<````.``````````````!H
MX&````````<````/``````````````!PX&````````<````0````````````
M``!XX&````````<````1``````````````"`X&````````<````2````````
M``````"(X&````````<````3``````````````"0X&````````<````4````
M``````````"8X&````````<````5``````````````"@X&````````<````6
M``````````````"HX&````````<````7``````````````"PX&````````<`
M```8``````````````"XX&````````<````9``````````````#`X&``````
M``<````:``````````````#(X&````````<````;``````````````#0X&``
M``````<````<``````````````#8X&````````<````=``````````````#@
MX&````````<````>``````````````#HX&````````<````?````````````
M``#PX&````````<````@``````````````#XX&````````<````A````````
M````````X6````````<````B```````````````(X6````````<````C````
M```````````0X6````````<````D```````````````8X6````````<```!.
M```````````````@X6````````<```!B```````````````HX6````````<`
M```E```````````````PX6````````<````F```````````````XX6``````
M``<````G``````````````!`X6````````<````H``````````````!(X6``
M``````<````I``````````````!0X6````````<````J``````````````!8
MX6````````<````K``````````````!@X6````````<````L````````````
M``!HX6````````<````M``````````````!PX6````````<````N````````
M``````!XX6````````<````O``````````````"`X6````````<````P````
M``````````"(X6````````<````Q``````````````"0X6````````<````R
M``````````````"8X6````````<````S``````````````"@X6````````<`
M```T``````````````"HX6````````<````U``````````````"PX6``````
M``<````V``````````````"XX6````````<````W``````````````#`X6``
M``````<````X``````````````#(X6````````<````Y``````````````#0
MX6````````<````Z``````````````#8X6````````<````[````````````
M``#@X6````````<````\``````````````#HX6````````<````]````````
M``````#PX6````````<````^``````````````#XX6````````<````_````
M````````````XF````````<```!````````````````(XF````````<```!!
M```````````````0XF````````<```!"```````````````8XF````````<`
M``!#```````````````@XF````````<```!$```````````````HXF``````
M``<```!%```````````````PXF````````<```!&```````````````XXF``
M``````<```!'``````````````!`XF````````<```!(``````````````!(
MXF````````<```!)``````````````!0XF````````<```!*````````````
M``!8XF````````<```!+``````````````!@XF````````<```!,````````
M``````!HXF````````<```!-``````````````!(@^P(Z"L%``#HN@4``.B5
M5P``2(/$",/_-8J_(`#_)8R_(``/'T``_R6*OR``:`````#IX/____\E@K\@
M`&@!````Z=#_____)7J_(`!H`@```.G`_____R5ROR``:`,```#IL/____\E
M:K\@`&@$````Z:#_____)6*_(`!H!0```.F0_____R5:OR``:`8```#I@/__
M__\E4K\@`&@'````Z7#_____)4J_(`!H"````.E@_____R5"OR``:`D```#I
M4/____\E.K\@`&@*````Z4#_____)3*_(`!H"P```.DP_____R4JOR``:`P`
M``#I(/____\E(K\@`&@-````Z1#_____)1J_(`!H#@```.D`_____R42OR``
M:`\```#I\/[___\E"K\@`&@0````Z>#^____)0*_(`!H$0```.G0_O___R7Z
MOB``:!(```#IP/[___\E\KX@`&@3````Z;#^____)>J^(`!H%````.F@_O__
M_R7BOB``:!4```#ID/[___\EVKX@`&@6````Z8#^____)=*^(`!H%P```.EP
M_O___R7*OB``:!@```#I8/[___\EPKX@`&@9````Z5#^____);J^(`!H&@``
M`.E`_O___R6ROB``:!L```#I,/[___\EJKX@`&@<````Z2#^____):*^(`!H
M'0```.D0_O___R6:OB``:!X```#I`/[___\EDKX@`&@?````Z?#]____)8J^
M(`!H(````.G@_?___R6"OB``:"$```#IT/W___\E>KX@`&@B````Z<#]____
M)7*^(`!H(P```.FP_?___R5JOB``:"0```#IH/W___\E8KX@`&@E````Z9#]
M____)5J^(`!H)@```.F`_?___R52OB``:"<```#I</W___\E2KX@`&@H````
MZ6#]____)4*^(`!H*0```.E0_?___R4ZOB``:"H```#I0/W___\E,KX@`&@K
M````Z3#]____)2J^(`!H+````.D@_?___R4BOB``:"T```#I$/W___\E&KX@
M`&@N````Z0#]____)1*^(`!H+P```.GP_/___R4*OB``:#````#IX/S___\E
M`KX@`&@Q````Z=#\____)?J](`!H,@```.G`_/___R7RO2``:#,```#IL/S_
M__\EZKT@`&@T````Z:#\____)>*](`!H-0```.F0_/___R7:O2``:#8```#I
M@/S___\ETKT@`&@W````Z7#\____)<J](`!H.````.E@_/___R7"O2``:#D`
M``#I4/S___\ENKT@`&@Z````Z4#\____);*](`!H.P```.DP_/___R6JO2``
M:#P```#I(/S___\EHKT@`&@]````Z1#\____)9J](`!H/@```.D`_/___R62
MO2``:#\```#I\/O___\EBKT@`&A`````Z>#[____)8*](`!H00```.G0^___
M_R5ZO2``:$(```#IP/O___\E<KT@`&A#````Z;#[____)6J](`!H1````.F@
M^____R5BO2``:$4```#ID/O___\E6KT@`&A&````Z8#[____)5*](`!H1P``
M`.EP^____R5*O2``:$@```#I8/O___\E0KT@`&A)````Z5#[____)3J](`!H
M2@```.E`^____R4RO2``:$L```#I,/O___\E*KT@`&A,````Z2#[____)2*]
M(`!H30```.D0^___,>U)B=%>2(GB2(/D\%!42<?`,'=``$C'P4!W0`!(Q\<2
M=$``Z`?\___TD)!(@^P(2(L%6;H@`$B%P'0"_]!(@\0(PY"0D)"0D)"0D)"0
MD)!52(GE4TB#[`B`/3B](```=4N[X-U@`$B+!3*](`!(@>O8W6``2,'[`TB#
MZP%(.=AS)&8/'T0``$B#P`%(B04-O2``_Q3%V-U@`$B+!?^\(`!(.=ARXL8%
MZ[P@``%(@\0(6\G#9F9F+@\?A```````54B#/<^W(```2(GE=!I!NP````!-
MA=MT#[_HW6``R4'_XV8/'T0``,G#D)!52(GE2(/L$$C'1?A(>$``OP````#H
MBO[__XL`B<?H$?K__TB+5?A(B=&ZH")``+Y2>$``2(G'Z$C^___)PU5(B>5!
M5%-(@>PP$```2(FUR.___TB)E<#O__]D2(L$)2@```!(B47H,<"X;GA``$B-
MC>#O__^Z_P\``$B)SDB)Q^A?_/__B87<[___@[W<[___`'X>BX7<[___@^@!
M2)@/MH0%X.___X3`=0>#K=SO__\!@[W<[___`'Y<BX7<[___2&/02(V%X.__
M_[XO````2(G'Z+SY__](A<!T.HN%W.___TQCX+\`````Z+3]__^+`(G'Z#OY
M__](C97@[___2(N=R.___TR)X4B)WDB)Q^B_^___ZRR_`````.B#_?__BP")
MQ^@*^?__2(N5P.___TB+C<CO__](B<Y(B<?H8?K__TB+1>AD2#,$)2@```!T
M!>@=_/__2('$,!```%M!7,G#54B)Y4%6055!5%-(@^P028G\2(EUV$V%Y'0,
M2(L%_[H@`$B%P'4*N`````#ID@```$R)X^L$2(/#`0^V`X3`=`</M@,\/77N
M2(G8B<),B>")T2G!B<A!B<9,BRW!NB``ZU-)8\9(B<),B>9(B=_H3OG__X7`
M=3I)8\9(C00##[8`/#UU+$R)ZDB+!9*Z(`!(B=%(*<%(B<A(P?@#B<)(BT78
MB1!)8\9(@\`!2(T$`^L228/%"$F+70!(A=MUI+@`````2(/$$%M!7$%=05[)
MPU5(B>5(@^P@2(E]Z$B-5?Q(BT7H2(G62(G'N`````#H#/___\G#54B)Y4%5
M05132(/L*$B)?<A)B?1!#[8$)#P]=01)@\0!3(GGZ)+Y__^)1=Q(C5782(M%
MR$B)UDB)Q[@`````Z,;^__](B<-(A=MT.4B)W^AG^?__BU7<2#G0#X($`0``
M00^V!"2(`P^V`X3`#Y7`2(/#`4F#Q`&$P'7EN`````#IHP$``$B+'9^Y(`!!
MO0````#K"$B#PPA!@\4!2(L#2(7`=?"+!>')(`"%P'0]08U%`DB82(T4Q0``
M``!(BP5HN2``2(G62(G'Z$W[__](B056N2``2(L%3[D@`$B%P'5>N/_____I
M/0$``,<%ELD@``$```!!C44"2)A(P>`#2(G'Z-3W__](B<-(A=MU"KC_____
MZ0\!``!)8\5(C13%`````$B+!0"Y(`!(B<9(B=_HA?G__TB)'>ZX(`#K`9!(
MBP7DN"``26/52(/"`4C!X@-(`=!(QP``````1(GHB478ZP&02(M=R.L$2(/#
M`0^V`X3`=`</M@,\/77N2(L%I[@@`(M5V(G22,'B`TR-+!!(B=B)PDB+1<B)
MT2G!B<@#1=R#P`*)P$B)Q^@K]___28E%`$F+10!(A<!U![C_____ZV1(BP5@
MN"``BU78B=)(P>(#2`'02(L8ZP1(@\,!2(M%R`^V`(@##[8#A,`/E<!(@T7(
M`83`=`</M@,\/77;Q@,]2(/#`4$/M@0DB`,/M@.$P`^5P$B#PP%)@\0!A,!U
MY;@`````2(/$*%M!7$%=R<-52(GE4TB#["A(B7W8ZRY(BP7BMR``BU7L2&/2
M2,'B`TB-'!!(C4,(2(L`2(D#2(L#2(7`=`9(@\,(Z^B02(U5[$B+1=A(B=9(
MB<>X`````.B"_/__2(7`=;5(@\0H6\G#54B)Y5-(@>PX(```9$B+!"4H````
M2(E%Z#'`2,>%P-___P````#HG/;__XG"NX%X0`!(C87@[___N8UX0`!(B=Y(
MB<>X`````.A)]___B87,W___@[W,W___`'D*N`````#IF@```$B-A>#O__](
MC8W0W___N@`0``!(B<Y(B<?H<O?__XF%S-___X.]S-___P!Y![@`````ZV:+
MA<S?__^#P`%(F$B)Q^B9]?__2(F%P-___TB#O<#?__\`=0>X`````.L[BX7,
MW___2&/02(V-T-___TB+A<#?__](B<Y(B<?H+_?__XN%S-___TB82`.%P-__
M_\8``$B+A<#?__](BU7H9$@S%"4H````=`7H<O?__TB!Q#@@``!;R<-52(GE
MZ-C^___)PU5(B>532('L2!```$B)O;CO__](B;6P[___9$B+!"4H````2(E%
MZ#'`OY%X0`"X`````.CD^___2(F%R.___TB+%>>U(`!(BX6X[___2(G62(G'
MZ%7V__](A<!T)4B+A;CO__](B<:_FGA``+@`````Z,S[__](BX6X[___Z48"
M``!(BX6X[___2(G'Z&SU__^)A=SO__](BQ67M2``2(N%L.___TB)UDB)Q^C-
M]O__2(F%T.___^G>`0``2(N%T.___P^V`(3`=0M(QX70[___IWA``$B#O<CO
M__\`=#U(BY70[___2(N%R.___TB)UDB)Q^AU]O__A<!U($B+!3*U(`!(B<:_
M`````.AM]O__2(F%T.___^E^`0``2(N%T.___TB)Q^C2]/__B878[___ZQF#
MK=CO__\!BX78[___2)A(`X70[___Q@``BX78[___2)A(@^@!2`.%T.___P^V
M$$B+!<2T(``/M@`XPG3#BX78[___@\`!`X7<[___/?\/``!^)4B+A;CO__](
MB<:_FGA``+@`````Z*/Z__](BX6X[___Z1T!``!(BPU[M"``NZEX0`!(B[6X
M[___2(N5T.___TB-A>#O__])B?!(B=Y(B<>X`````.B.]/__OP````#HI/;_
M_XL`B<?H*_+__TB)Q^BC]?__2(G"2(V%X.___TB)UDB)Q^AN20``A<!U;+\`
M````Z'#V__^+`(G'Z/?Q__](B<?H;_7__XM`&"4`\```/0"```!U0DB-A>#O
M__^^`0```$B)Q^C\]?__A<!U*DB-A>#O__](B<:_FGA``+@`````Z-3Y__](
MC87@[___2(G'Z,#T___K24B+!:^S(`!(B<:_`````.CJ]/__2(F%T.___TB#
MO=#O__\`#X44_O__2(N%N.___TB)QK^:>$``N`````#H@?G__TB+A;CO__](
MBU7H9$@S%"4H````=`7H@?3__TB!Q$@0``!;R<-52(GE2(E]Z$B+1>A(B47X
M2(M%Z$B)1?#K)DB+1?`/MA!(BP4?LR``#[8`.,)U#$B+1?!(@\`!2(E%^$B#
M1?`!2(M%\`^V`(3`=<](BT7XR<-52(GE4TB#[!A(B7WH2(-]Z`!T"TB+1>@/
MM@"$P'4/OZ=X0`#HW?/__^GP````2(M%Z$B)Q^B,\O__2(/H`4B)PT@#7>CK
M!$B#ZP%(.UWH=A</MA-(BP6;LB``#[8`.,)TY>L$2(/K`4@[7>AV$0^V$TB+
M!7ZR(``/M@`XPG7E2#M=Z'4N#[832(L%9[(@``^V`#C"=0R_IWA``.AF\___
MZWQ(BP5-LB``2(G'Z%7S___K:TB#ZP%(.UWH=A$/MA-(BP4OLB``#[8`.,)T
MY4B)VDB+1>A(B=%(*<%(B<A(@\`"2#T`$```=@>X`````.LM2(G:2(M%Z$B)
MT4@IP4B)R$B#P`%(B<)(BT7H2(G&OR#C8`#HC?/__[@@XV``2(/$&%O)PU5(
MB>5(@^Q`9$B+!"4H````2(E%^#'`2(L%DT@``$B)1=!(BP602```2(E%V$B+
M!8U(``!(B47@2(L%BD@``$B)1>@/MP6'2```9HE%\+^P>$``N`````#HO/G_
M_[_`>$``N`````#HK?G__[^1>$``N`````#HGOG__[_,>$``N`````#HC_G_
M_[_6>$``N`````#H@/G__[_@>$``N`````#H<?G__[^:>$``N`````#H8OG_
M_[_J>$``N`````#H4_G__[_S>$``N`````#H1/G__[_^>$``N`````#HW/;_
M_TB)1<A(@WW(`'062(M%R$B)QK_6>$``N`````#HX?;__[\/>4``N`````#H
MK/;__TB)1<A(@WW(`'062(M%R$B)QK\A>4``N`````#HL?;__[\L>4``N```
M``#H?/;__TB)1<A(@WW(`'082(M%R$B)QK^1>$``N`````#H@?;__^MROSQY
M0`"X`````.A*]O__2(E%R$B#?<@`=!A(BT7(2(G&O\QX0`"X`````.A/]O__
MZT!(C4702(/`$4B)1<A(BT7(N@H```"^37E``$B)Q^CV[O__A<!U&DB+1<A(
M@\`*2(G&O\QX0`"X`````.@-]O__OEAY0`"_L'A``+@`````Z/GU__](BT7X
M9$@S!"4H````=`7H`/'__\G#54B)Y4B#[!"+!="O(`"#^/]U0K_,>$``N```
M``#HF_7__TB)1?A(@WWX`'0=2(M%^`^V`(3`=!)(BT7X#[8`/#!T![@!````
MZP6X`````(D%B:\@`(L%@Z\@`,G#54B)Y5-(@>QP`@``2(F]&/W__TB+A1C]
M__](@\`X2(E%X,=%[`````#IL0```$B+1>!(BP!(B4782(-%X`B+1>Q(BU78
M2,'B&(/B_TB+3=A(P>$(@>$``/\`2`G12(M5V$C!Z@B!X@#_``!("=%(BU78
M2,'J&('B_P```$@)RDB82(F4Q2#]__](P6W8((M%[(U(`4B+1=A(P>`8@^#_
M2(M5V$C!X@B!X@``_P!("<)(BT782,'H""4`_P``2`G"2(M%V$C!Z!@E_P``
M`$@)PDACP4B)E,4@_?__@T7L`H-][`\/CD7____'1>P0````Z90```"+3>R+
M1>R#Z`-(F$B+E,4@_?__BT7L@^@(2)A(BX3%(/W__T@QPHM%[(/H#DB82(N$
MQ2#]__](,<*+1>R#Z!!(F$B+A,4@_?__2#'"2&/!2(F4Q2#]__^+3>R+1>Q(
MF$B+A,4@_?__2(T4`(M%[$B82(N$Q2#]__](P>@?2`G02(G"@^+_2&/!2(F4
MQ2#]__^#1>P!@WWL3P^.8O___TB+A1C]__](BP!(B4702(N%&/W__TB+0`A(
MB47(2(N%&/W__TB+0!!(B47`2(N%&/W__TB+0!A(B46X2(N%&/W__TB+0"!(
MB46P2(V%(/W__TB)1:A(BT702(G"2,'B!4B+1=!(P>@;2`G0@^#_2(M5P$B+
M3<A((=%(BU7(2/?22"-5N$@)RD@!T$B)PD@#5;!(BT6H2(L`2(T$`D@%F7F"
M6H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%
MV$B)PDC!X@5(BT782,'H&T@)T(/@_TB+5<A(BTW02"'12(M5T$CWTD@C5<!(
M"<I(`=!(B<)(`U6X2(M%J$B+`$B-!`)(!9EY@EJ#X/](B46P2(-%J`A(BT70
M2(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%L$C!Z!M(
M"="#X/](BU702(M-V$@AT4B+5=A(]])((U7(2`G*2`'02(G"2`-5P$B+1:A(
MBP!(C00"2`69>8):@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H`D@)
MT(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G0@^#_2(M5V$B+3;!((=%(
MBU6P2/?22"-5T$@)RD@!T$B)PD@#5<A(BT6H2(L`2(T$`D@%F7F"6H/@_TB)
M1<!(@T6H"$B+1;!(B<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!
MX@5(BT7`2,'H&T@)T(/@_TB+5;!(BTVX2"'12(M5N$CWTD@C5=A("<I(`=!(
MB<)(`U702(M%J$B+`$B-!`)(!9EY@EJ#X/](B47(2(-%J`A(BT6X2(G"2,'B
M'DB+1;A(P>@"2`G0@^#_2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("="#X/](
MBU6X2(M-P$@AT4B+5<!(]])((U6P2`G*2`'02(G"2`-5V$B+1:A(BP!(C00"
M2`69>8):@^#_2(E%T$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)
M1<!(BT702(G"2,'B!4B+1=!(P>@;2`G0@^#_2(M5P$B+3<A((=%(BU7(2/?2
M2"-5N$@)RD@!T$B)PD@#5;!(BT6H2(L`2(T$`D@%F7F"6H/@_TB)1=A(@T6H
M"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT78
M2,'H&T@)T(/@_TB+5<A(BTW02"'12(M5T$CWTD@C5<!("<I(`=!(B<)(`U6X
M2(M%J$B+`$B-!`)(!9EY@EJ#X/](B46P2(-%J`A(BT702(G"2,'B'DB+1=!(
MP>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%L$C!Z!M("="#X/](BU702(M-
MV$@AT4B+5=A(]])((U7(2`G*2`'02(G"2`-5P$B+1:A(BP!(C00"2`69>8):
M@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT6X
M2(G"2,'B!4B+1;A(P>@;2`G0@^#_2(M5V$B+3;!((=%(BU6P2/?22"-5T$@)
MRD@!T$B)PD@#5<A(BT6H2(L`2(T$`D@%F7F"6H/@_TB)1<!(@T6H"$B+1;!(
MB<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!X@5(BT7`2,'H&T@)
MT(/@_TB+5;!(BTVX2"'12(M5N$CWTD@C5=A("<I(`=!(B<)(`U702(M%J$B+
M`$B-!`)(!9EY@EJ#X/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"2`G0
M@^#_2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("="#X/](BU6X2(M-P$@AT4B+
M5<!(]])((U6P2`G*2`'02(G"2`-5V$B+1:A(BP!(C00"2`69>8):@^#_2(E%
MT$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B
M!4B+1=!(P>@;2`G0@^#_2(M5P$B+3<A((=%(BU7(2/?22"-5N$@)RD@!T$B)
MPD@#5;!(BT6H2(L`2(T$`D@%F7F"6H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>
M2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T(/@_TB+
M5<A(BTW02"'12(M5T$CWTD@C5<!("<I(`=!(B<)(`U6X2(M%J$B+`$B-!`)(
M!9EY@EJ#X/](B46P2(-%J`A(BT702(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%
MT$B+1;!(B<)(P>(%2(M%L$C!Z!M("="#X/](BU702(M-V$@AT4B+5=A(]])(
M(U7(2`G*2`'02(G"2`-5P$B+1:A(BP!(C00"2`69>8):@^#_2(E%N$B#1:@(
M2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(
MP>@;2`G0@^#_2(M5V$B+3;!((=%(BU6P2/?22"-5T$@)RD@!T$B)PD@#5<A(
MBT6H2(L`2(T$`D@%F7F"6H/@_TB)1<!(@T6H"$B+1;!(B<)(P>(>2(M%L$C!
MZ`)("="#X/](B46P2(M%P$B)PDC!X@5(BT7`2,'H&T@)T(/@_TB+5;!(BTVX
M2"'12(M5N$CWTD@C5=A("<I(`=!(B<)(`U702(M%J$B+`$B-!`)(!9EY@EJ#
MX/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"2`G0@^#_2(E%N$B+1<A(
MB<)(P>(%2(M%R$C!Z!M("="#X/](BU6X2(M-P$@AT4B+5<!(]])((U6P2`G*
M2`'02(G"2`-5V$B+1:A(BP!(C00"2`69>8):@^#_2(E%T$B#1:@(2(M%P$B)
MPDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G0
M@^#_2(M5P$B+3<A((=%(BU7(2/?22"-5N$@)RD@!T$B)PD@#5;!(BT6H2(L`
M2(T$`D@%F7F"6H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#
MX/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T(/@_TB+5<A(BTW02"'12(M5
MT$CWTD@C5<!("<I(`=!(B<)(`U6X2(M%J$B+`$B-!`)(!9EY@EJ#X/](B46P
M2(-%J`A(BT702(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%
M2(M%L$C!Z!M("=!(B<*#XO](BT702(M-V$@QR$@S1<A(C00"2(G"2`-5P$B+
M1:A(BP!(C00"2`6AZ]EN@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H
M`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G02(G"@^+_2(M%V$B+
M3;!(,<A(,T702(T$`DB)PD@#5<A(BT6H2(L`2(T$`D@%H>O9;H/@_TB)1<!(
M@T6H"$B+1;!(B<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!X@5(
MBT7`2,'H&T@)T$B)PH/B_TB+1;!(BTVX2#'(2#-%V$B-!`)(B<)(`U702(M%
MJ$B+`$B-!`)(!:'KV6Z#X/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"
M2`G0@^#_2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<*#XO](BT6X2(M-
MP$@QR$@S1;!(C00"2(G"2`-5V$B+1:A(BP!(C00"2`6AZ]EN@^#_2(E%T$B#
M1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+
M1=!(P>@;2`G02(G"@^+_2(M%P$B+3<A(,<A(,T6X2(T$`DB)PD@#5;!(BT6H
M2(L`2(T$`D@%H>O9;H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)(
M"="#X/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)PH/B_TB+1<A(BTW0
M2#'(2#-%P$B-!`)(B<)(`U6X2(M%J$B+`$B-!`)(!:'KV6Z#X/](B46P2(-%
MJ`A(BT702(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%
ML$C!Z!M("=!(B<*#XO](BT702(M-V$@QR$@S1<A(C00"2(G"2`-5P$B+1:A(
MBP!(C00"2`6AZ]EN@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H`D@)
MT(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G02(G"@^+_2(M%V$B+3;!(
M,<A(,T702(T$`DB)PD@#5<A(BT6H2(L`2(T$`D@%H>O9;H/@_TB)1<!(@T6H
M"$B+1;!(B<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!X@5(BT7`
M2,'H&T@)T$B)PH/B_TB+1;!(BTVX2#'(2#-%V$B-!`)(B<)(`U702(M%J$B+
M`$B-!`)(!:'KV6Z#X/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"2`G0
M@^#_2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<*#XO](BT6X2(M-P$@Q
MR$@S1;!(C00"2(G"2`-5V$B+1:A(BP!(C00"2`6AZ]EN@^#_2(E%T$B#1:@(
M2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(
MP>@;2`G02(G"@^+_2(M%P$B+3<A(,<A(,T6X2(T$`DB)PD@#5;!(BT6H2(L`
M2(T$`D@%H>O9;H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#
MX/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)PH/B_TB+1<A(BTW02#'(
M2#-%P$B-!`)(B<)(`U6X2(M%J$B+`$B-!`)(!:'KV6Z#X/](B46P2(-%J`A(
MBT702(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%L$C!
MZ!M("=!(B<*#XO](BT702(M-V$@QR$@S1<A(C00"2(G"2`-5P$B+1:A(BP!(
MC00"2`6AZ]EN@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@
M_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G02(G"@^+_2(M%V$B+3;!(,<A(
M,T702(T$`DB)PD@#5<A(BT6H2(L`2(T$`D@%H>O9;H/@_TB)1<!(@T6H"$B+
M1;!(B<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!X@5(BT7`2,'H
M&T@)T$B)PH/B_TB+1;!(BTVX2#'(2#-%V$B-!`)(B<)(`U702(M%J$B+`$B-
M!`)(!:'KV6Z#X/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"2`G0@^#_
M2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("=!(B<*#XO](BT6X2(M-P$@QR$@S
M1;!(C00"2(G"2`-5V$B+1:A(BP!(C00"2`6AZ]EN@^#_2(E%T$B#1:@(2(M%
MP$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;
M2`G02(G"@^+_2(M%P$B+3<A(,<A(,T6X2(T$`DB)PD@#5;!(BT6H2(L`2(T$
M`D@%H>O9;H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](
MB47(2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)PH/B_TB+1<A(BTW02#'(2#-%
MP$B-!`)(B<)(`U6X2(M%J$B+`$B-!`)(!:'KV6Z#X/](B46P2(-%J`A(BT70
M2(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%L$C!Z!M(
M"=!(B<*#XO](BT702(M-V$@QR$@S1<A(C00"2(G"2`-5P$B+1:A(BP!(C00"
M2`6AZ]EN@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)
M1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G02(G"@^+_2(M%V$B+3;!(,<A(,T70
M2(T$`DB)PD@#5<A(BT6H2(L`2(T$`D@%H>O9;H/@_TB)1<!(@T6H"$B+1;!(
MB<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!X@5(BT7`2,'H&T@)
MT(/@_TB+5=A(BTVP2`G*2"-5N$B+3=A(BUVP2"'92`G*2`'02(G"2`-5T$B+
M1:A(BP!(`<*XW+P;CTB-!`*#X/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(
MP>@"2`G0@^#_2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("="#X/](BU6P2(M-
MN$@)RD@C5<!(BTVP2(M=N$@AV4@)RD@!T$B)PD@#5=A(BT6H2(L`2`'"N-R\
M&X](C00"@^#_2(E%T$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)
M1<!(BT702(G"2,'B!4B+1=!(P>@;2`G0@^#_2(M5N$B+3<!("<I((U7(2(M-
MN$B+7<!((=E("<I(`=!(B<)(`U6P2(M%J$B+`$@!PKC<O!N/2(T$`H/@_TB)
M1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!
MX@5(BT782,'H&T@)T(/@_TB+5<!(BTW(2`G*2"-5T$B+3<!(BUW(2"'92`G*
M2`'02(G"2`-5N$B+1:A(BP!(`<*XW+P;CTB-!`*#X/](B46P2(-%J`A(BT70
M2(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%L$C!Z!M(
M"="#X/](BU7(2(M-T$@)RD@C5=A(BTW(2(M=T$@AV4@)RD@!T$B)PD@#5<!(
MBT6H2(L`2`'"N-R\&X](C00"@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT78
M2,'H`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G0@^#_2(M5T$B+
M3=A("<I((U6P2(M-T$B+7=A((=E("<I(`=!(B<)(`U7(2(M%J$B+`$@!PKC<
MO!N/2(T$`H/@_TB)1<!(@T6H"$B+1;!(B<)(P>(>2(M%L$C!Z`)("="#X/](
MB46P2(M%P$B)PDC!X@5(BT7`2,'H&T@)T(/@_TB+5=A(BTVP2`G*2"-5N$B+
M3=A(BUVP2"'92`G*2`'02(G"2`-5T$B+1:A(BP!(`<*XW+P;CTB-!`*#X/](
MB47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"2`G0@^#_2(E%N$B+1<A(B<)(
MP>(%2(M%R$C!Z!M("="#X/](BU6P2(M-N$@)RD@C5<!(BTVP2(M=N$@AV4@)
MRD@!T$B)PD@#5=A(BT6H2(L`2`'"N-R\&X](C00"@^#_2(E%T$B#1:@(2(M%
MP$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;
M2`G0@^#_2(M5N$B+3<!("<I((U7(2(M-N$B+7<!((=E("<I(`=!(B<)(`U6P
M2(M%J$B+`$@!PKC<O!N/2(T$`H/@_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%
MR$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T(/@_TB+5<!(
MBTW(2`G*2"-5T$B+3<!(BUW(2"'92`G*2`'02(G"2`-5N$B+1:A(BP!(`<*X
MW+P;CTB-!`*#X/](B46P2(-%J`A(BT702(G"2,'B'DB+1=!(P>@"2`G0@^#_
M2(E%T$B+1;!(B<)(P>(%2(M%L$C!Z!M("="#X/](BU7(2(M-T$@)RD@C5=A(
MBTW(2(M=T$@AV4@)RD@!T$B)PD@#5<!(BT6H2(L`2`'"N-R\&X](C00"@^#_
M2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT6X2(G"
M2,'B!4B+1;A(P>@;2`G0@^#_2(M5T$B+3=A("<I((U6P2(M-T$B+7=A((=E(
M"<I(`=!(B<)(`U7(2(M%J$B+`$@!PKC<O!N/2(T$`H/@_TB)1<!(@T6H"$B+
M1;!(B<)(P>(>2(M%L$C!Z`)("="#X/](B46P2(M%P$B)PDC!X@5(BT7`2,'H
M&T@)T(/@_TB+5=A(BTVP2`G*2"-5N$B+3=A(BUVP2"'92`G*2`'02(G"2`-5
MT$B+1:A(BP!(`<*XW+P;CTB-!`*#X/](B47(2(-%J`A(BT6X2(G"2,'B'DB+
M1;A(P>@"2`G0@^#_2(E%N$B+1<A(B<)(P>(%2(M%R$C!Z!M("="#X/](BU6P
M2(M-N$@)RD@C5<!(BTVP2(M=N$@AV4@)RD@!T$B)PD@#5=A(BT6H2(L`2`'"
MN-R\&X](C00"@^#_2(E%T$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@
M_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G0@^#_2(M5N$B+3<!("<I((U7(
M2(M-N$B+7<!((=E("<I(`=!(B<)(`U6P2(M%J$B+`$@!PKC<O!N/2(T$`H/@
M_TB)1=A(@T6H"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)
MPDC!X@5(BT782,'H&T@)T(/@_TB+5<!(BTW(2`G*2"-5T$B+3<!(BUW(2"'9
M2`G*2`'02(G"2`-5N$B+1:A(BP!(`<*XW+P;CTB-!`*#X/](B46P2(-%J`A(
MBT702(G"2,'B'DB+1=!(P>@"2`G0@^#_2(E%T$B+1;!(B<)(P>(%2(M%L$C!
MZ!M("="#X/](BU7(2(M-T$@)RD@C5=A(BTW(2(M=T$@AV4@)RD@!T$B)PD@#
M5<!(BT6H2(L`2`'"N-R\&X](C00"@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(
MBT782,'H`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G0@^#_2(M5
MT$B+3=A("<I((U6P2(M-T$B+7=A((=E("<I(`=!(B<)(`U7(2(M%J$B+`$@!
MPKC<O!N/2(T$`H/@_TB)1<!(@T6H"$B+1;!(B<)(P>(>2(M%L$C!Z`)("="#
MX/](B46P2(M%P$B)PDC!X@5(BT7`2,'H&T@)T(/@_TB+5=A(BTVP2`G*2"-5
MN$B+3=A(BUVP2"'92`G*2`'02(G"2`-5T$B+1:A(BP!(`<*XW+P;CTB-!`*#
MX/](B47(2(-%J`A(BT6X2(G"2,'B'DB+1;A(P>@"2`G0@^#_2(E%N$B+1<A(
MB<)(P>(%2(M%R$C!Z!M("="#X/](BU6P2(M-N$@)RD@C5<!(BTVP2(M=N$@A
MV4@)RD@!T$B)PD@#5=A(BT6H2(L`2`'"N-R\&X](C00"@^#_2(E%T$B#1:@(
M2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(
MP>@;2`G02(G"@^+_2(M%P$B+3<A(,<A(,T6X2(T$`DB)PD@#5;!(BT6H2(L`
M2`'"N-;!8LI(C00"@^#_2(E%V$B#1:@(2(M%R$B)PDC!XAY(BT7(2,'H`D@)
MT(/@_TB)1<A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_2(M%R$B+3=!(
M,<A(,T7`2(T$`DB)PD@#5;A(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%L$B#
M1:@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT6P2(G"2,'B!4B+
M1;!(P>@;2`G02(G"@^+_2(M%T$B+3=A(,<A(,T7(2(T$`DB)PD@#5<!(BT6H
M2(L`2`'"N-;!8LI(C00"@^#_2(E%N$B#1:@(2(M%V$B)PDC!XAY(BT782,'H
M`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G02(G"@^+_2(M%V$B+
M3;!(,<A(,T702(T$`DB)PD@#5<A(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%
MP$B#1:@(2(M%L$B)PDC!XAY(BT6P2,'H`D@)T(/@_TB)1;!(BT7`2(G"2,'B
M!4B+1<!(P>@;2`G02(G"@^+_2(M%L$B+3;A(,<A(,T782(T$`DB)PD@#5=!(
MBT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%R$B#1:@(2(M%N$B)PDC!XAY(BT6X
M2,'H`D@)T(/@_TB)1;A(BT7(2(G"2,'B!4B+1<A(P>@;2`G02(G"@^+_2(M%
MN$B+3<!(,<A(,T6P2(T$`DB)PD@#5=A(BT6H2(L`2`'"N-;!8LI(C00"@^#_
M2(E%T$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"
M2,'B!4B+1=!(P>@;2`G02(G"@^+_2(M%P$B+3<A(,<A(,T6X2(T$`DB)PD@#
M5;!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%V$B#1:@(2(M%R$B)PDC!XAY(
MBT7(2,'H`D@)T(/@_TB)1<A(BT782(G"2,'B!4B+1=A(P>@;2`G02(G"@^+_
M2(M%R$B+3=!(,<A(,T7`2(T$`DB)PD@#5;A(BT6H2(L`2`'"N-;!8LI(C00"
M@^#_2(E%L$B#1:@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT6P
M2(G"2,'B!4B+1;!(P>@;2`G02(G"@^+_2(M%T$B+3=A(,<A(,T7(2(T$`DB)
MPD@#5<!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%N$B#1:@(2(M%V$B)PDC!
MXAY(BT782,'H`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(P>@;2`G02(G"
M@^+_2(M%V$B+3;!(,<A(,T702(T$`DB)PD@#5<A(BT6H2(L`2`'"N-;!8LI(
MC00"@^#_2(E%P$B#1:@(2(M%L$B)PDC!XAY(BT6P2,'H`D@)T(/@_TB)1;!(
MBT7`2(G"2,'B!4B+1<!(P>@;2`G02(G"@^+_2(M%L$B+3;A(,<A(,T782(T$
M`DB)PD@#5=!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%R$B#1:@(2(M%N$B)
MPDC!XAY(BT6X2,'H`D@)T(/@_TB)1;A(BT7(2(G"2,'B!4B+1<A(P>@;2`G0
M2(G"@^+_2(M%N$B+3<!(,<A(,T6P2(T$`DB)PD@#5=A(BT6H2(L`2`'"N-;!
M8LI(C00"@^#_2(E%T$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)
M1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G"@^+_2(M%P$B+3<A(,<A(,T6X
M2(T$`DB)PD@#5;!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%V$B#1:@(2(M%
MR$B)PDC!XAY(BT7(2,'H`D@)T(/@_TB)1<A(BT782(G"2,'B!4B+1=A(P>@;
M2`G02(G"@^+_2(M%R$B+3=!(,<A(,T7`2(T$`DB)PD@#5;A(BT6H2(L`2`'"
MN-;!8LI(C00"@^#_2(E%L$B#1:@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@
M_TB)1=!(BT6P2(G"2,'B!4B+1;!(P>@;2`G02(G"@^+_2(M%T$B+3=A(,<A(
M,T7(2(T$`DB)PD@#5<!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%N$B#1:@(
M2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT6X2(G"2,'B!4B+1;A(
MP>@;2`G02(G"@^+_2(M%V$B+3;!(,<A(,T702(T$`DB)PD@#5<A(BT6H2(L`
M2`'"N-;!8LI(C00"@^#_2(E%P$B#1:@(2(M%L$B)PDC!XAY(BT6P2,'H`D@)
MT(/@_TB)1;!(BT7`2(G"2,'B!4B+1<!(P>@;2`G02(G"@^+_2(M%L$B+3;A(
M,<A(,T782(T$`DB)PD@#5=!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%R$B#
M1:@(2(M%N$B)PDC!XAY(BT6X2,'H`D@)T(/@_TB)1;A(BT7(2(G"2,'B!4B+
M1<A(P>@;2`G02(G"@^+_2(M%N$B+3<!(,<A(,T6P2(T$`DB)PD@#5=A(BT6H
M2(L`2`'"N-;!8LI(C00"@^#_2(E%T$B#1:@(2(M%P$B)PDC!XAY(BT7`2,'H
M`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G"@^+_2(M%P$B+
M3<A(,<A(,T6X2(T$`DB)PD@#5;!(BT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%
MV$B#1:@(2(M%R$B)PDC!XAY(BT7(2,'H`D@)T(/@_TB)1<A(BT782(G"2,'B
M!4B+1=A(P>@;2`G02(G"@^+_2(M%R$B+3=!(,<A(,T7`2(T$`DB)PD@#5;A(
MBT6H2(L`2`'"N-;!8LI(C00"@^#_2(E%L$B#1:@(2(M%T$B)PDC!XAY(BT70
M2,'H`D@)T(/@_TB)1=!(BX48_?__2(L`2`-%L$B)PH/B_TB+A1C]__](B1!(
MBX48_?__2(M`"$@#1=A(B<*#XO](BX48_?__2(E0"$B+A1C]__](BT`02`-%
MT$B)PH/B_TB+A1C]__](B5`02(N%&/W__TB+0!A(`T7(2(G"@^+_2(N%&/W_
M_TB)4!A(BX48_?__2(M`($@#1<!(B<*#XO](BX48_?__2(E0($B!Q'`"``!;
MR<-52(GE2(E]^$B+1?A(QP`!(T5G2(M%^,=`"(FKS>_'0`P`````2(M%^,=`
M$/[<NIC'0!0`````2(M%^$C'0!AV5#(02(M%^,=`(/#ATL/'0"0`````2(M%
M^$C'0"@`````2(M%^$C'0#``````2(M%^,=`>`````#)PU5(B>5(@^PP2(E]
MZ$B)=>")5=Q(BT7H2(M`*(M5W$ACTDC!X@-(`="#X/](B47P2(M%Z$B+0"A(
M.T7P=A1(BT7H2(M`,$B-4`%(BT7H2(E0,$B+1>A(BU7P2(E0*$B+1>A(BT`P
MBU7<2&/22,'J'4B-%!!(BT7H2(E0,$B+1>B+0'B%P`^$N0```$B+1>B+0'BZ
M0````(G1*<&)R(E%_(M%_#M%W'X&BT7<B47\BT7\2&/02(M%Z$B-2#A(BT7H
MBT!X2)A(`<%(BT7@2(G&2(G/Z,''__^+1?PI1=R+1?Q(F$@!1>!(BT7HBT!X
MB<(#5?Q(BT7HB5!X2(M%Z(M`>(/X0'5N2(M%Z$B)Q^A6U___ZS%(BT7H2(U(
M.$B+1>"Z0````$B)QDB)S^AIQ___2(-%X$"#;=Q`2(M%Z$B)Q^@CU___@WW<
M/W_)BT7<2&/02(M%Z$B-2#A(BT7@2(G&2(G/Z#''__](BT7HBU7<B5!XZP&0
MR<-52(GE2(/L$$B)??A(B77P2(M%\$B)Q^C5UO__2(M%\$B+`$C!Z!B)PDB+
M1?B($$B+1?A(C5`!2(M%\$B+`$C!Z!"(`DB+1?A(C5`"2(M%\$B+`$C!Z`B(
M`DB+1?A(C5`#2(M%\$B+`(@"2(M%^$B-4`1(BT7P2(M`"$C!Z!B(`DB+1?A(
MC5`%2(M%\$B+0`A(P>@0B`)(BT7X2(U0!DB+1?!(BT`(2,'H"(@"2(M%^$B-
M4`=(BT7P2(M`"(@"2(M%^$B-4`A(BT7P2(M`$$C!Z!B(`DB+1?A(C5`)2(M%
M\$B+0!!(P>@0B`)(BT7X2(U0"DB+1?!(BT`02,'H"(@"2(M%^$B-4`M(BT7P
M2(M`$(@"2(M%^$B-4`Q(BT7P2(M`&$C!Z!B(`DB+1?A(C5`-2(M%\$B+0!A(
MP>@0B`)(BT7X2(U0#DB+1?!(BT`82,'H"(@"2(M%^$B-4`](BT7P2(M`&(@"
M2(M%^$B-4!!(BT7P2(M`($C!Z!B(`DB+1?A(C5`12(M%\$B+0"!(P>@0B`)(
MBT7X2(U0$DB+1?!(BT`@2,'H"(@"2(M%^$B-4!-(BT7P2(M`((@"R<-52(GE
M2(/L,$B)?=A(B7702(M%T$B+0"A(B47P2(M%T$B+0#!(B47H2(M%\$C!Z`.#
MX#^)1?Q(BT702(U0.(M%_$B82(T$`L8`@(-%_`&#??PX?E.X0````"M%_$B8
M2(M5T$B-2CB+5?Q(8])(`=%(B<*^`````$B)S^A'PO__2(M%T$B)Q^BJU/__
M2(M%T$B#P#BZ.````+X`````2(G'Z"'"___K*[@X````*T7\2)A(BU702(U*
M.(M5_$ACTD@!T4B)PKX`````2(G/Z/3!__](BT7H2,'H&(G"2(M%T(A0<$B+
M1>A(P>@0B<)(BT70B%!Q2(M%Z$C!Z`B)PDB+1="(4')(BT7HB<)(BT70B%!S
M2(M%\$C!Z!B)PDB+1="(4'1(BT7P2,'H$(G"2(M%T(A0=4B+1?!(P>@(B<)(
MBT70B%!V2(M%\(G"2(M%T(A0=TB+5=!(BT782(G62(G'Z-_\___)PU5(B>5(
M@^P02,=%^`````!(QT7P`````.BBQ/__B<?HF\+__TB)1?!(@WWP`'0+2(M%
M\$B+`$B)1?A(BT7XR<-52(GE2(/L$$B)??B_`````.A)Q?__BP")Q^C0P/__
M2(G'Z$C$__](B<)(BT7X2(G62(G'Z"88``"%P'5POP````#H&,7__XL`B<?H
MG\#__TB)Q^@7Q/__BT`8)0#P```]`$```'0JOP````#H[L3__XL`B<?H=<#_
M_TB)Q^CMP___BT`8)0#P```]`*```'4<2(M%^+X"````2(G'Z'W$__^%P'4'
MN`$```#K!;@`````R<-52(GE4TB#[&A(B7V82,=%X`````!(QT78`````$C'
M1:"">4``2,=%J))Y0`!(QT6PFGE``$C'1;BG>4``2,=%P*QY0`!(QT7(OGE`
M`$C'1=``````QT7L`````.GH````2(M%X$B)Q[@`````Z,C'__](B4782(-]
MV`!T"TB+1=@/M@"$P'4=2(M5F$B+1>!(B=9(B<>X`````.C`Q___Z:````!(
MBU682(M%V$B)UDB)Q^@3PO__2(7`#X6$````2(M%F$B)Q^A.P?__2(G#2(L%
M?($@`$B)Q^@\P?__2`'#2(M%V$B)Q^@MP?__2(T$`TB#P`)(B<?H/<#__TB)
M1=!(BPU*@2``NZEX0`!(BW782(M5F$B+1=!)B?!(B=Y(B<>X`````.A>P?__
M2(M5T$B+1>!(B=9(B<>X`````.@;Q___@T7L`8M%[$B82(M$Q:!(B47@2(M%
MX`^V`(3`#X7[_O__2(/$:%O)PU5(B>5!54%44TB![+B!``!(B;TX?O__9$B+
M!"4H````2(E%V#'`2,>%Z'[__P````!(QX7@?O__`````$C'A=A^__\`````
M2,>%<'[__[]Y0`!(QX5X?O__QWE``$C'A8!^__^G>$``2,>%B'[__[YY0`!(
MQX5`?O__(7E``$C'A4A^___,>4``2,>%4'[__]-Y0`!(QX58?O__VWE``$C'
MA6!^___@>4``2,>%:'[__[YY0`!(QX60?O__Y'E``$C'A9A^___I>4``2,>%
MH'[__[YY0`!(QX70?O__\GE``$C'A<A^__^^>4``2,>%P'[__P````!(QX6X
M?O__`````$C'A;!^__\`````QX7\?O__`````+^1>$``N`````#HI\7__TB)
MA=A^__](@[W8?O__`'0Q2(N%V'[__P^V`(3`="-(BX78?O__2(G'Z#_]__](
MBX78?O__2(G'Z(O`___IX@8``+@`````Z"W\__](B86X?O__2(.]N'[__P!U
M?<>%#'___P````#K0DB+A>!^__](B<>X`````.@JQ?__2(F%V'[__TB#O=A^
M__\`=!9(BX78?O__2(G'Z"O`__](B86X?O__@X4,?___`4B#O;A^__\`=26+
MA0Q___](F$B+A,60?O__2(F%X'[__TB+A>!^__\/M@"$P'6/2(.]N'[__P!U
M#4C'A;A^___W>4``ZUI(BX6X?O__2(F%\'[__^L\Z,*^__](BQ!(BX7P?O__
M#[8`2`^^P$@!P$B-!`(/MP`/M\"#X`B%P'4*2(N%\'[__\8`7TB#A?!^__\!
M2(N%\'[__P^V`(3`=;;'A0Q___\`````ZU5(BX7@?O__2(G'N`````#H/,3_
M_TB)A=A^__](@[W8?O__`'0I2(N%V'[__TB)Q^@N^___A<!T%DB+A=A^__](
MB<?H*K___TB)A>A^__^#A0Q___\!2(.]Z'[__P!U*8N%#'___TB82(N$Q4!^
M__](B87@?O__2(N%X'[__P^V`(3`#X5X____QX4,?___`````.LP2(N%V'[_
M_TB)Q^B_^O__A<!T%DB+A=A^__](B<?HN[[__TB)A>A^__^#A0Q___\!2(.]
MZ'[__P!U)8N%#'___TB82(N$Q7!^__](B878?O__2(N%V'[__P^V`(3`=:%(
MBX7H?O__2(G'Z"^]__^)PTB+A=!^__](B<?H'KW__P'#2(N%N'[__TB)Q^@-
MO?__`<-(BX7(?O__2(G'Z/R\__^-!`,%``0``(F%_'[__XN%_'[__TB82(G'
MZ/Z[__](B86P?O__2(L-`'T@`+O^>4``2(N]N'[__TB+M=!^__](BY7H?O__
M2(N%L'[__TF)^4F)\$B)WDB)Q[@`````Z`F]__](BX6P?O__ONT!``!(B<?H
M5;___[^G>4``N`````#HE<+__TB)A=A^__](@[W8?O__`'0N2(N%V'[__TB)
MQ^B6O?__2(G"2(N%.'[__TB+`$B)UDB)Q^A!QO__2(F%P'[__TB#O<!^__\`
M=1%(BX4X?O__2(L`2(F%P'[__[@`````Z'3,__^%P`^%7P(``$B+A<!^__^^
M`````$B)Q[@`````Z)&\__^)A0A___^#O0A___\`#X0S`@``BX4(?___N@(`
M``!(Q\;N____B<?HU;W__TB-C1!___^+A0A___^Z!@```$B)SHG'Z*FZ__\/
MMH40?___A,`/A<\````/MH41?___/$,/A<`````/MH42?___/$$/A;$````/
MMH43?___/$,/A:(````/MH44?___/$@/A9,````/MH45?___/$4/A80```"+
MA0A___^Z`@```$C'QL;___^)Q^A&O?__2(V-$'___XN%"'___[HI````2(G.
MB<?H&KK__TR+)4-[(`"[!WI``$B+A;!^__](B<?H_[K__T@#A;!^__](BXW(
M?O__2(V5$'___TF)R$B)T4R)XDB)WDB)Q[@`````Z$&[__^0Z3@"``!(C840
M____2(G'Z)OR___K'XN5!'___TB-C1!___](C840____2(G.2(G'Z/3R__](
MC8T0?___BX4(?___N@"```!(B<Z)Q^A_N?__B84$?___@[T$?___`'^VBX4(
M?___B<?HP[C__TB-E1#___](C47`2(G62(G'Z-?U___'A0!___\`````ZSZ+
MA0!___](F`^V1`7`#[;0N11Z0`"+A0!___\!P$ACV$B-19!(`=A(B<Y(B<>X
M`````.AZNO__@X4`?___`8.]`'___Q-^N<9%N`!,BR4?>B``NP=Z0`!(BX6P
M?O__2(G'Z-NY__](`X6P?O__2(N-R'[__TB-59!)B<A(B=%,B>)(B=Y(B<>X
M`````.@@NO__Z1@!``#'A?A^__\`````2(N%L'[__TB)Q^B2N?__2(F%J'[_
M_[Y8>4``O\QX0`"X`````.B\O___Z!*Y__]!B<5,BR68>2``NQEZ0`!(BX6P
M?O__2(G'Z%2Y__](`X6P?O__2(N5R'[__TF)T$2)Z4R)XDB)WDB)Q[@`````
MZ)VY___K;TB+A:A^__](BY6P?O__2(T$`L8``(.%^'[__P'HJKC__T&)Q4R+
M)3!Y(`"[)7I``$B+A;!^__](B<?H[+C__T@#A;!^__](BXW(?O__BY7X?O__
M28G)08G01(GI3(GB2(G>2(G'N`````#H++G__TB+A;!^__^^[0$``$B)Q^AX
MN___@_C_=1#HSKG__XL`@_@1#X1H____2(N%L'[__TB)QK^1>$``N`````#H
MO[[__TB+A;!^__](B<?H4/;__TB+A;!^__](BU789$@S%"4H````=`7HL+G_
M_TB!Q+B!``!;05Q!7<G#54B)Y5-(@>S(````2(F]./___TC'1=``````2(.]
M./___P`/A&@!``!(BX4X____#[8`A,`/A%D!``!(BX4X____2(G'Z`BX__](
MB47@2(-]X``/A?\```#I-P$``$B+1=A(@\`3OJ=X0`!(B<?H/[G__X7`#X3>
M````2(M%V$B#P!.^-'I``$B)Q^@BN?__A<`/A,$```!(BX4X____2(G'Z)NW
M__^)PTB+1=A(@\`32(G'Z(FW__^-!`.#P`*)1>R+1>Q(F$B)Q^B3MO__2(E%
MT$B+1=A(C4@3NS=Z0`!(BY4X____2(M%T$B)WDB)Q[@`````Z+>W__](BT70
M2(V50/___TB)UDB)Q^BQ#```@_C_=""+A5C___\E`/```#T`0```=0Y(BT70
M2(G'Z,S^___K#$B+1=!(B<?H<+;__TB+1=!(B<?HY+;__TC'1=``````ZP&0
M2(M%X$B)Q^B=N?__2(E%V$B#?=@`#X7J_O__2(M%X$B)Q^CRN/__2(N%./__
M_TB)Q^@SMO__ZP20ZP&02('$R````%O)PU5(B>5(@^P@2(E]Z$B+1>A(B<?H
MQ</__TB)1?A(BT7X2(G'Z&3#__](B47PN`````#HS\;__X7`=#5(@WWH`'0N
M2(M%Z`^V`(3`="-(BT7POO)Y0`!(B<?H]K;__T@[1?!U#$B+1>A(B<?H\OW_
M_\G#54B)Y5-(@^P82(EUZ+\`````Z*NX__^+`(G'Z#*T__](B<?H.K3__TB+
M`$B+6`B_`````.B)N/__BP")Q^@0M/__2(G'Z+BT__\/M@"(0R"_`````.AH
MN/__BP")Q^COL___2(G'Z/>S__](BP!(BU@(OP````#H1KC__XL`B<?HS;/_
M_TB)Q^B%M/__2(L`#[=`(&8E_P%FB4,BOP````#H'+C__XL`B<?HH[/__TB)
MQ^BKL___2(L`2(M8"+\`````Z/JW__^+`(G'Z(&S__^Z`````+Z^>4``2(G'
MZ&^W__](B4,HOP````#HT;?__XL`B<?H6+/__TB)Q^A@L___2(L`2(M8"+\`
M````Z*^W__^+`(G'Z#:S__](B<?HKK/__TB+`$B)0S"_`````.B-M___BP")
MQ^@4L___2(G'Z!RS__](BP!(BU@(OP````#H:[?__XL`B<?H\K+__TB)Q^A:
MMO__2(L`2(7`=">_`````.A(M___BP")Q^C/LO__2(G'Z#>V__](BP!(BX"H
M````ZP6X`````$B)0SB_`````.@8M___BP")Q^B?LO__2(G'Z*>R__](BP!(
MBT`(2,=`0`````"_`````.CNMO__BP")Q^AULO__2(G'Z'VR__](BP!(BT`(
M2,=`2`````"_`````.C$MO__BP")Q^A+LO__2(G'Z%.R__](BP!(BU@(OP``
M``#HHK;__XL`B<?H*;+__TB)Q^A!MO__2(L`2(E#4$B#Q!A;R<-52(GE2(/L
M$$B)=?B_`````.AMMO__BP")Q^CTL?__OO____](B<?HI[/__[\`````Z$VV
M__^+`(G'Z-2Q__^Z`````+X>;$``2(G'Z(*V___)PU5(B>5!5%-(@^Q02(EU
MJ,=%Z`````"_`````.@0MO__BP")Q^B7L?__2(G'Z(^S___&``&_L'A``+@`
M````Z'RY__](B47`2(-]P`!T&DB+1<`/M@`\,74/2(M%P$B#P`$/M@"$P'0*
MN`````#HC<'__[\`````Z+2U__^+`(G'Z#NQ__^Y"P```+H!````OCUZ0`!(
MB<?H9++__TB)1>!(@WW@``^$.@$``$B+1>!(BT`02(M`*$B)1=C'1>P!````
MZ;T```"+1>Q$C6#_OP````#H6+7__XL`B<?HW[#__TB+7=BY`````$2)XDB)
MWDB)Q^B(L___2(E%T$B#?=``#X2.````2(M%T$B+`(M`#"4`!```A<!T#4B+
M1=!(BP!(BT`0ZR](BT702(L8OP````#H^+3__XL`B<?H?[#__[D"````N@``
M``!(B=Y(B<?H.K7__TB+%0MS(`"+3>Q(8\E(P>$#2`'*2(L22(G&2(G7Z)BS
M__^%P'4<@T7H`8-%[`&+!=9R(``Y1>P/C#3____K!)#K`9"+!<%R(`"#Z`$[
M1>AU/L=%[`$```#K*K\`````Z':T__^+`(G'Z/VO__](BU782(G62(G'Z!ZQ
M__](B47(@T7L`8L%@'(@`#E%['S+OP````#H0;3__XL`B<?HR*___[D%````
MN@$```"^0GI``$B)Q^CQL/__2(E%X$B#?>``=&Y(BT7@2(M`$$B+&+\`````
MZ`&T__^+`(G'Z(BO__^Z1'I``$B)WDB)Q^CHL/__2(M%X$B+0!!(BP"+0`PE
M``!``(7`="E(BT7@2(M`$$B+&+\`````Z+RS__^+`(G'Z$.O__](B=Y(B<?H
M:++__[\`````Z)ZS__^+`(G'Z"6O__^Y!0```+H!````ODEZ0`!(B<?H3K#_
M_TB)1>!(@WW@``^$AP```$C'1;@`````OYIX0`"X`````.CGMO__2(E%N$B#
M?;@`="](BT7@2(M`$$B+&+\`````Z#BS__^+`(G'Z+^N__](BU6X2(G>2(G'
MZ""P___K-DB+!4]Q(`!,BR!(BT7@2(M`$$B+&+\`````Z/^R__^+`(G'Z(:N
M__],B>)(B=Y(B<?H@K3__[\`````Z-ZR__^+`(G'Z&6N__](B<?H7;#__\8`
M`+\`````Z,"R__^+`(G'Z$>N__](B<?HS[+__TC'``````"_D7A``+@`````
MZ"BV__](B06Z<"``2(L%LW`@`$B%P`^%!0$``$B+!;-P(`!(B<?H->___TB)
M!91P(`!(BQV=<"``2(M%X$B+0!!(BP"+0`PE``0``(7`=!%(BT7@2(M`$$B+
M`$B+0!#K,TB+1>!(BT`03(L@OP````#H*++__XL`B<?HKZW__[D"````N@``
M``!,B>9(B<?H:K+__TB)WDB)Q^@?KO__B47L2(M%X$B+0!!(BP"+0`PE``0`
M`(7`=!%(BT7@2(M`$$B+`$B+0!#K,TB+1>!(BT`02(L8OP````#HO['__XL`
MB<?H1JW__[D"````N@````!(B=Y(B<?H`;+__TB+%=)O(`!(BQJ+5>R)T4B)
MPDB)WK]0>D``N`````#HK;#__TB+!9YO(`"^[0$``$B)Q^BIL?__B47L@WWL
M`'0R@WWL$70L@WWL_W0F2(L5=6\@`$B+!7YO(`!(BP"+3>Q(B<:_@'I``+@`
M````Z%ZP__](@\106T%<R<-52(GEOP````#H%['__XL`B<?HGJS__TB)Q^AB
MLO__OP````#H_+#__XL`B<?H@ZS__T&Y`````$&XOGE``+F^>4``NK!N0`"^
MSGI``$B)Q^C`KO__R<-52(GE4TB#[#B)?=Q(B7702(E5R$B-5<A(C4W02(U%
MW$B)SDB)Q^B3L/__NN`@0`"^X"!``+^P(D``Z+\"``"_`````.C%K?__#[8`
MA,!U3^BIK?__2(D%DFX@`$B+!8MN(`!(A<!U"K\!````Z(RL__](BP5U;B``
M2(G'Z$VN__^_`````.A#L/__BP")Q^C*J___2(G'Z'*O___&``"_`````.@E
ML/__BP")Q^BLJ___2(G'Z"2P__\/MA"#R@*($+\`````Z`*P__^+`(G'Z(FK
M__](B<?H`;#__P^V$(/*`8@0BT7<@\`%2)A(A<!X!_)(#RK`ZQ5(B<)(T>J#
MX`%("<+R2`\JPO(/6,!F#U?)\@]8P68/+@7`!0``#Y?`A,!T#[_0XF``N```
M``#HRJ[__XM%W(/`!4B82,'@`TB)Q^CVKO__2(D%MVT@`$B+!;!M(`!(BU70
M2(L22(D02(L%GVT@`$B#P`A(QP#C>D``2(L%C6T@`$B#P!!(QP`@>T``QP5P
M;2```P```$B+!7%M(`"+%6-M(`!(8])(P>(#2`'02,<`YGI``(L%3&T@`(/`
M`8D%0VT@`,=%Z`$```#K.$B+%3MM(`"+!2UM(``#1>A(F$B#Z`%(P>`#2`'"
M2(M%T(M-Z$ACR4C!X0-(`<A(BP!(B0*#1>@!BT7<.47H?,!(BP7[;"``BTW<
MBQ7J;"``C1012&/22(/J`4C!X@-(`=!(QP``````2(L5TVP@`(M-W(L%PFP@
M`(T$`8U8_TB+!:5L(`!!N`````!(B=&)VKZ[<T``2(G'Z$VJ__^)1>R#?>P`
M=1)(BP5];"``2(G'Z`6K__^)1>Q(BP5K;"``2(G'Z-.L__^_P'A``+@`````
MZ,.Q__](A<!U/4B+!5!L(`!(A<!U%K^1>$``N`````#HH['__TB)!35L(`!(
MBP4N;"``2(7`=`](BP4B;"``2(G'Z+_T__](BP4+;"``2(G'Z).I___H?JO_
M_XM%[$B#Q#A;R<.0D)"02(T%86L@`#')2(7`=`=(BPU3:R``Z1:J__^0D)"0
MD)#SPV9F9F9F+@\?A```````2(EL)-A,B7PD^$B-+7-F(`!,C3UL9B``3(ED
M).!,B6PDZ$R)="3P2(E<)-!(@^PX3"G]08G^28GU2,']`TF)U.C#J/__2(7M
M=!PQVP\?0`!,B>),B>Y$B?=!_Q3?2(/#`4@YZW+J2(M<)`A(BVPD$$R+9"08
M3(ML)"!,BW0D*$R+?"0P2(/$.,.0D)"0D)"02(GR2(G^OP$```#I8*S__TB)
M\DB)_K\!````Z7"K__]52(GE4TB#[`A(BP7(92``2(/X_W09N\C=8``/'T0`
M`$B#ZPC_T$B+`TB#^/]U\4B#Q`A;R<.0D$B#[`CH;ZW__TB#Q`C#````````
M``````$``@``````<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@`O<')O8R]S96QF+V5X90`O`#H`+W!R;V,O)6DO)7,`97AE`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`N`"5S)7,E<P!005)?24Y)5$E!3$E:140`4$%2
M7U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%2
M1T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U0
M1$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X`4$%27T-,14%./0`Q`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@``!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!
M5$@`4$%42`!$64Q$7TQ)0E)!4EE?4$%42```0SI<5$5-4``O=&UP`%1-4$1)
M4@!414U01$E2`%1%35``5$U0`%5315(`55-%4DY!344`<&%R+0!365-414T`
M)7,E<R5S)7,`)7-C86-H92TE<R5S`"4P,G@`)7-T96UP+25U)7,`)7-T96UP
M+25U+25U)7,`+BX`)7,O)7,`05)'5@`8`'!E<FP`,````````"5S.B!E>&5C
M=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`"UE`"TM``````````````````#`0P``````````<&%R+G!L````````
M```````````````````````````C(2]U<W(O8FEN+W!E<FP*"F5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R
M7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U
M;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@
M,34Y"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI4
M96UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@
M1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D
M:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S
M"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O
M;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N
M('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@
M("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@
M=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL
M(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y
M('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N
M(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@
M("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@
M("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U0
M3$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)
M6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@
M("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@
M("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S
M92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q
M*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@
M?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?
M:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@
M)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!
M4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D
M,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@
M)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=6
M7R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC
M(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I
M9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@
M<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE
M<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T
M>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D[
M"@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N
M<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I
M+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E
M86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T
M.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@
M("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@
M("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@
M("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X
M="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U
M="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M
M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@
M/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@
M(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N
M(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F
M.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@
M("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D
M9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`
M24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@
M("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@
M("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@
M("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K
M97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@
M("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@
M)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*
M("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M
M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@
M("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]
M+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[
M>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*
M("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@
M9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D
M(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M
M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@
M(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@
M("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G
M<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@
M("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@
M<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["@HC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O
M<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@
M("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@
M("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@
M("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(&UY($!A9&1?=&]?
M:6YC.PH@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC
M+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@
M("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@
M>PH@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=S:71E
M)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@
M("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@
M("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@
M)U0G*2!["B`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@
M?0H*("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@(&EF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("!D96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@
M("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("!E>&ET
M.PH@("`@("`@('T*("`@('T*"B`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@
M?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T
M*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*
M("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@
M("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D
M;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U
M="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@
M(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@
M("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@
M("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E
M96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*
M("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F
M.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*
M("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@
M("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*
M"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H
M)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@
M("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,[
M"@H@("`@("`@(&EF("@D0V]N9FEG>U]D96QI;7T@97$@)UQ<)RD@>R!S>UQ<
M?7LO?6<@9F]R($!I;F,@?0H*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@
M861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM
M97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI
M8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@
M9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@
M("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N
M9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I
M;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>
M7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@
M)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@
M("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I
M.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@
M("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@
M("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@
M*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D
M92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@
M("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@
M("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J
M(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^
M(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@
M("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP
M;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%
M(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*
M("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@
M4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B
M(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@
M("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U
M+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A
M<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N
M86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I
M="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@
M("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z
M("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@
M("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@
M("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*
M("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@
M/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@
M("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@
M("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]
M"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@
M=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T
M:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL
M93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA
M3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I
M8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@
M("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@
M<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@
M("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@
M979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E
M(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A
M"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@
M9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@
M("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*
M("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@
M("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@
M("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU
M."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@
M("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]
M"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@
M("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY
M("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*
M"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M
M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I
M;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E
M9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D
M92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE
M(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA
M;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N
M86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@
M("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@
M("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D
M*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@
M("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@
M("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@
M("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E
M("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@
M("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I
M9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO
M9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`
M7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N
M9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T
M:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@
M+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`P,@H*
M7U]%3D1?7PH````!&P,['`$``"(```"L4?__.`$``.I1__]8`0``#U/__W@!
M``#?4___H`$```54___``0``.%;__^`!``"95O__``(``+A7__\@`@``PU?_
M_T`"``"I6O__8`(``/I:__^``@``'US__Z`"```B7O__P`(``']>___@`@``
MGX7__P`#```9AO__(`,``(Z'__]``P``2HG__V`#``"QBO__@`,``/&*__^@
M`P``I8O__\`#```2C?__X`,``'Z5__\(!```'9?__R@$``".E___2`0``,V9
M__]H!```()K__X@$```KG___J`0``(*?___(!```@*+__^@$``"@HO__``4`
M`+"B__\8!0``0*/__T`%``!0H___6`4````````4``````````%Z4@`!>!`!
M&PP'")`!```<````'````&Q0__\^`````$$.$$.&`@T&`````````!P````\
M````BE#__R4!````00X00X8"#09^@P2,`P``)````%P```"/4?__T`````!!
M#A!#A@(-!DZ#!HP%C02.`P```````!P```"$````-U+__R8`````00X00X8"
M#08`````````'````*0````]4O__,P(```!!#A!#A@(-!E"#!8P$C0,<````
MQ````%!4__]A`````$$.$$.&`@T&2X,#`````!P```#D````D53__Q\!````
M00X00X8"#09B@P,`````'`````0!``"05?__"P````!!#A!#A@(-!@``````
M```<````)`$``'M5___F`@```$$.$$.&`@T&;X,#`````!P```!$`0``05C_
M_U$`````00X00X8"#08`````````'````&0!``!R6/__)0$```!!#A!#A@(-
M!E"#`P`````<````A`$``'=9__\#`@```$$.$$.&`@T&`````````!P```"D
M`0``6EO__UT`````00X00X8"#08`````````'````,0!``"76___("<```!!
M#A!#A@(-!FJ#`P`````<````Y`$``)>"__]Z`````$$.$$.&`@T&````````
M`!P````$`@``\8+__W4!````00X00X8"#08`````````'````"0"``!&A/__
MO`$```!!#A!#A@(-!@`````````<````1`(``.*%__]G`0```$$.$$.&`@T&
M`````````!P```!D`@``*8?__T``````00X00X8"#08`````````'````(0"
M``!)A___M`````!!#A!#A@(-!@`````````<````I`(``-V'__]M`0```$$.
M$$.&`@T&`EV#`P```"0```#$`@``*HG__VP(````00X00X8"#08#'0&#!8P$
MC0,````````<````[`(``&Z1__^?`0```$$.$$.&`@T&98,#`````!P````,
M`P``[9+__W$`````00X00X8"#08`````````'````"P#```^D___/P(```!!
M#A!#A@(-!DZ#`P`````<````3`,``%V5__]3`````$$.$$.&`@T&````````
M`!P```!L`P``D)7__PL%````00X00X8"#097@P2,`P``'````(P#``![FO__
M5P````!!#A!#A@(-!@`````````<````K`,``+*:___Z`@```$$.$$.&`@T&
M8H,#`````!0```#,`P``D)W__QH``````````````!0```#D`P``F)W__P(`
M`````````````"0```#\`P``D)W__XD`````2H\"A@9F#D"#!XX#C02,!0``
M```````4````)`0``/B=__\0```````````````4````/`0``/"=__\0````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````/__________````````
M``#__________P`````````````````````!``````````$``````````0``
M``````"R`@````````$`````````O0(````````!`````````,<"````````
M`0`````````6`P````````$`````````.@0````````,`````````$@@0```
M````#0`````````H>$````````0`````````>`)```````#U_O]O`````-`%
M0```````!0````````"($4````````8`````````V`9````````*````````
M`,X%````````"P`````````8`````````!4````````````````````#````
M`````.C?8````````@````````!0!P```````!0`````````!P`````````7
M`````````/@80```````!P````````"P&$````````@`````````2```````
M```)`````````!@`````````_O__;P````!`&$```````/___V\``````@``
M``````#P__]O`````%870```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#PW6``````````
M``````````````````!V($```````(8@0```````EB!```````"F($``````
M`+8@0```````QB!```````#6($```````.8@0```````]B!````````&(4``
M`````!8A0```````)B%````````V(4```````$8A0```````5B%```````!F
M(4```````'8A0```````AB%```````"6(4```````*8A0```````MB%`````
M``#&(4```````-8A0```````YB%```````#V(4````````8B0```````%B)`
M```````F(D```````#8B0```````1B)```````!6(D```````&8B0```````
M=B)```````"&(D```````)8B0```````IB)```````"V(D```````,8B0```
M````UB)```````#F(D```````/8B0```````!B-````````6(T```````"8C
M0```````-B-```````!&(T```````%8C0```````9B-```````!V(T``````
M`(8C0```````EB-```````"F(T```````+8C0```````QB-```````#6(T``
M`````.8C0```````]B-````````&)$```````!8D0```````)B1````````V
M)$```````$8D0```````5B1```````!F)$```````'8D0```````AB1`````
M``"6)$```````*8D0```````MB1```````#&)$```````-8D0```````YB1`
M``````#V)$````````8E0```````%B5````````F)4```````#8E0```````
M1B5`````````````````````````````?7A```````!_>$```````/____\`
M`````'M```````!M60````````!'0T,Z("A58G5N='4@-"XS+C,M.'5B=6YT
M=3(I(#0N,RXS``!'0T,Z("A58G5N='4@-"XS+C,M.'5B=6YT=3(I(#0N,RXS
M``!'0T,Z("A58G5N='4@-"XT+C`M,'5B=6YT=38I(#0N-"XP``!'0T,Z("A5
M8G5N='4@-"XT+C`M,'5B=6YT=38I(#0N-"XP``!'0T,Z("A58G5N='4@-"XT
M+C`M,'5B=6YT=38I(#0N-"XP``!'0T,Z("A58G5N='4@-"XS+C,M.'5B=6YT
M=3(I(#0N,RXS``!'0T,Z("A58G5N='4@-"XS+C,M.'5B=6YT=3(I(#0N,RXS
M``!'0T,Z("A58G5N='4@-"XS+C,M.'5B=6YT=3(I(#0N,RXS``!'0T,Z("A5
M8G5N='4@-"XS+C,M.'5B=6YT=3(I(#0N,RXS``!'0T,Z("A58G5N='4@-"XT
M+C`M,'5B=6YT=38I(#0N-"XP``!'0T,Z("A58G5N='4@-"XS+C,M.'5B=6YT
M=3(I(#0N,RXS```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YG
M;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
M<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S
M`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````#@"0```
M````.`(````````<`````````````````````0```````````````````!,`
M```'`````@````````!4`D```````%0"````````(```````````````````
M``0````````````````````E````!0````(`````````>`)```````!X`@``
M`````%0#````````!0`````````(``````````0`````````(0```/;__V\"
M`````````-`%0```````T`4````````$`0````````4`````````"```````
M`````````````"L````+`````@````````#8!D```````-@&````````L`H`
M```````&`````0````@`````````&``````````S`````P````(`````````
MB!%```````"($0```````,X%```````````````````!````````````````
M````.P```/___V\"`````````%870```````5A<```````#D``````````4`
M`````````@`````````"`````````$@```#^__]O`@````````!`&$``````
M`$`8````````<``````````&`````@````@```````````````````!7````
M!`````(`````````L!A```````"P&````````$@`````````!0`````````(
M`````````!@`````````80````0````"`````````/@80```````^!@`````
M``!0!P````````4````,````"``````````8`````````&L````!````!@``
M``````!(($```````$@@````````&`````````````````````0`````````
M``````````!F`````0````8`````````8"!```````!@(````````/`$````
M```````````````$`````````!``````````<0````$````&`````````%`E
M0```````4"4```````#84@``````````````````$```````````````````
M`'<````!````!@`````````H>$```````"AX````````#@``````````````
M``````0```````````````````!]`````0````(`````````0'A```````!`
M>````````$Y<```````````````````@````````````````````A0````$`
M```"`````````)#40```````D-0````````<`0``````````````````!```
M`````````````````),````!`````@````````"PU4```````+#5````````
M5`0```````````````````@```````````````````"=`````0````,`````
M````R-U@``````#(W0```````!`````````````````````(````````````
M````````I`````$````#`````````-C=8```````V-T````````0````````
M````````````"````````````````````*L````!`````P````````#HW6``
M`````.C=````````"`````````````````````@```````````````````"P
M````!@````,`````````\-U@``````#PW0```````/`!````````!@``````
M```(`````````!``````````N0````$````#`````````.#?8```````X-\`
M```````(````````````````````"``````````(`````````+X````!````
M`P````````#HWV```````.C?````````B`(```````````````````@`````
M````"`````````#'`````0````,`````````<.)@``````!PX@```````#@`
M```````````````````(````````````````````S0````@````#````````
M`,#B8```````J.(```````!H$```````````````````(```````````````
M`````-(````!`````````````````````````*CB````````C`$`````````
M``````````$````````````````````!`````P``````````````````````
J```TY````````-L````````````````````!````````````````````
